*** Program for generating refomr plots in Czech  
* The input dataset is taxbenchars_`u'_`t' (or wintervals_`u'_`t' for tax rate intervals)
* Use the reform numbers (`u'_`t') as a parameter, such that same set of figures may be generated for another reform comparison

capture program drop plotsczreform
program define plotsczreform
args u t

	capture log close
	clear
	capture clear matrix
	set more off
	set memory 512m


* We will consistently plot and compute summary stats for annual incomes above at least one monthly minimum wage
* Set the minimum here as a parameter to be able to change it in one step
scalar inclb = 7999

cd output_`u'_`t'
use taxbenchars_`u'_`t'
capture mkdir plotscz_`u'_`t'
cd plotscz_`u'_`t'

***********************************************************
*** PLOTS ***** 
***********************************************************

*** Change in the total (absolute) tax (individuals) - Czech version****
* Total tax for combining by wage/business
lpoly totaltax_w_`u'_`t' ginc_w if ginc_w>inclb & ginc_w<2000000, yscale(r(-100000 30000)) ylabel(-100000 (25000) 25000) yline(0) title("prijmy ze zamestnani") xtitle("hruba mzda (CZK/rok)") ytitle("zmena celkovych dani (CZK/rok)") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(totaltax_w_title_cz, replace)
lpoly totaltax_b_`u'_`t' ginc_b if ginc_b>inclb & ginc_b<2000000, yscale(r(-100000 30000)) ylabel(-100000 (25000) 25000) title("prijmy z podnikani") xtitle("hruby zisk (CZK/rok)") ytitle("") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(totaltax_b_title_cz, replace)
* totaltax for combining with densities
lpoly totaltax_w_`u'_`t' ginc_w if ginc_w>inclb & ginc_w<2000000, yscale(r(-100000 30000)) ylabel(-100000 (25000) 25000) yline(0) title("") xsca(alt) yline(0) xtitle("hruba mzda (CZK/rok)") ytitle("zmena celkovych dani (CZK/rok)") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(totaltax_w_cz, replace) 
lpoly totaltax_b_`u'_`t' ginc_b if ginc_b>inclb & ginc_b<2000000, yscale(r(-100000 30000)) ylabel(-100000 (25000) 25000) title("") xsca(alt) yline(0) xtitle("hruby zisk (CZK/rok)") ytitle("zmena celkovych dani (CZK/rok)") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(totaltax_b_cz, replace) 
* Histograms of tax rates and incomes
hist totaltax_w_`u'_`t' [fw=rpkoef] if ginc_w>inclb & ginc_w<2000000, frac horizontal xsca(alt) yscale(alt r(-100000 30000)) ylabel(-100000 (25000) 25000) yline(0) ytitle("zmena celkovych dani (CZK/rok)") xtitle("podil poplatniku") fxsize(33) name(hist_totaltax_w_cz, replace) nodraw
hist totaltax_b_`u'_`t' [fw=rpkoef] if ginc_b>inclb & ginc_b<2000000, frac horizontal xsca(alt) yscale(alt r(-100000 30000)) ylabel(-100000 (25000) 25000) yline(0) ytitle("zmena celkovych dani (CZK/rok)") xtitle("podil poplatniku") fxsize(33) name(hist_totaltax_b_cz, replace) nodraw
hist ginc_w 	[fw=rpkoef] if ginc_w>inclb & ginc_w<2000000, frac xtitle("hruba mzda (CZK/rok)") ytitle("podil poplatniku") fysize(25) name(hist_ginc_w_cz, replace) nodraw
hist ginc_b 	[fw=rpkoef] if ginc_b>inclb & ginc_b<2000000, frac xtitle("hruby zisk (CZK/rok)") ytitle("podil poplatniku") fysize(25) name(hist_ginc_b_cz, replace) nodraw
* Combine work and business
graph combine totaltax_w_title_cz totaltax_b_title_cz, ycommon title("Zmena celkovych dani") saving(totaltax_w_b_cz, replace) nodraw 
* Combine totaltax and histograms
graph combine totaltax_w_cz hist_totaltax_w_cz hist_ginc_w_cz, title("Zmena celkovych dani: prijmy ze zamestnani") imargin() nodraw saving(totaltax_w_densities_cz, replace)
graph combine totaltax_b_cz hist_totaltax_b_cz hist_ginc_b_cz, title("Zmena celkovych dani: prijmy z podnikani") imargin() nodraw saving(totaltax_b_densities_cz, replace)


*** Change in ATR -  Czech version
* ATR for combining by wage/business 
lpoly pATR_w_`u'_`t' ginc_w if ginc_w>inclb & ginc_w<2000000 & pATR_w_`u'_`t'<0.75 & pATR_w_`u'_`t'>-0.25, yline(0) ysc(r(-0.25 0.75)) ylabel(-0.25 (0.25) 0.75) title("prijmy ze zamestnani") xtitle("hruba mzda (CZK/rok)") ytitle("zmena ATR") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(ATR_w_title_cz, replace) 
lpoly pATR_b_`u'_`t' ginc_b if ginc_b>inclb & ginc_b<2000000 & pATR_b_`u'_`t'<0.75 & pATR_b_`u'_`t'>-0.25, yline(0) ysc(r(-0.25 0.75)) ylabel(-0.25 (0.25) 0.75) title("prijmy z podnikani") xtitle("hruby zisk (CZK/rok)") ytitle("") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(ATR_b_title_cz, replace) 
* ATR for combining with densities
lpoly pATR_w_`u'_`t' ginc_w if ginc_w>inclb & ginc_w<2000000 & pATR_w_`u'_`t'<0.75 & pATR_w_`u'_`t'>-0.25, title("") xsca(alt) yline(0) ysc(r(-0.25 0.75)) ylabel(-0.25 (0.25) 0.75) xtitle("hruba mzda (CZK/rok)") ytitle("zmena ATR") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(ATR_w_cz, replace) 
lpoly pATR_b_`u'_`t' ginc_b if ginc_b>inclb & ginc_b<2000000 & pATR_b_`u'_`t'<0.75 & pATR_b_`u'_`t'>-0.25, title("") xsca(alt) yline(0) ysc(r(-0.25 0.75)) ylabel(-0.25 (0.25) 0.75) xtitle("hruby zisk (CZK/rok)") ytitle("zmena ATR") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(ATR_b_cz, replace) 
* Histograms of tax rates and incomes
hist pATR_w_`u'_`t' [fw=rpkoef] if ginc_w>inclb & ginc_w<2000000 & pATR_w_`u'_`t'<0.75 & pATR_w_`u'_`t'>-0.25, frac horizontal xsca(alt) ysca(alt) yline(0) ysc(r(-0.25 0.75)) ylabel(-0.25 (0.25) 0.75) ytitle("zmena ATR") xtitle("podil poplatniku") fxsize(33) name(hist_ATR_w_cz, replace) nodraw
hist pATR_b_`u'_`t' [fw=rpkoef] if ginc_b>inclb & ginc_b<2000000 & pATR_b_`u'_`t'<0.75 & pATR_b_`u'_`t'>-0.25, frac horizontal xsca(alt) ysca(alt) yline(0) ysc(r(-0.25 0.75)) ylabel(-0.25 (0.25) 0.75) ytitle("zmena ATR") xtitle("podil poplatniku") fxsize(33) name(hist_ATR_b_cz, replace) nodraw
hist ginc_w 	[fw=rpkoef] if ginc_w>inclb & ginc_w<2000000 & pATR_w_`u'_`t'<0.75 & pATR_w_`u'_`t'>-0.25, frac xtitle("hruba mzda (CZK/rok)") ytitle("podil poplatniku") fysize(25) name(hist_ginc_w_cz, replace) nodraw
hist ginc_b 	[fw=rpkoef] if ginc_b>inclb & ginc_b<2000000 & pATR_b_`u'_`t'<0.75 & pATR_b_`u'_`t'>-0.25, frac xtitle("hruby zisk (CZK/rok)") ytitle("podil poplatniku") fysize(25) name(hist_ginc_b_cz, replace) nodraw
* Combine work and business
graph combine ATR_w_title_cz ATR_b_title_cz, title("Zmena prumernych danovych sazeb") ycommon nodraw saving(ATR_w_b_cz, replace)
* Combine ATR and histograms
graph combine ATR_w_cz hist_ATR_w_cz, title("Zmena prumernych danovych sazeb: prijmy ze zamestnani") imargin() nodraw saving(ATR_w_densities_cz, replace)
graph combine ATR_b_cz hist_ATR_b_cz, title("Zmena prumernych danovych sazeb: prijmy z podnikani") imargin() nodraw saving(ATR_b_densities_cz, replace)


**** Change in - EMTR all (taxes and benefits withrawals) - Czech version
* EMTR for combibing by wage and business
lpoly mtr_all_w_`u'_`t' ginc_w if ginc_w>inclb & ginc_w<2000000 & mtr_all_w_`u'_`t'<0.33 & mtr_all_w_`u'_`t'>-0.33, ysca(r(-0.33 0.33)) yline(0) ylabel(-0.3 (0.1) 0.3) title("prijmy ze zamestnani") xtitle("hruba mzda (CZK/rok)") ytitle("zmena EMTR") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(MTR_all_w_title_cz, replace)
lpoly mtr_all_b_`u'_`t' ginc_b if ginc_b>inclb & ginc_b<2000000 & mtr_all_b_`u'_`t'<0.33 & mtr_all_b_`u'_`t'>-0.33, ysca(r(-0.33 0.33)) yline(0) ylabel(-0.3 (0.1) 0.3) title("prijmy z podnikani") xtitle("hruby zisk (CZK/rok)") ytitle("") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(MTR_all_b_title_cz, replace)
* EMTR for combining with densities
lpoly mtr_all_w_`u'_`t' ginc_w if ginc_w>inclb & ginc_w<2000000 & mtr_all_w_`u'_`t'<0.33 & mtr_all_w_`u'_`t'>-0.33, ysca(r(-0.33 0.33)) yline(0) ylabel(-0.3 (0.1) 0.3) title("") xtitle("hruba mzda (CZK/rok)") ytitle("zmena EMTR") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(MTR_all_w_cz, replace) 
lpoly mtr_all_b_`u'_`t' ginc_b if ginc_b>inclb & ginc_b<2000000 & mtr_all_b_`u'_`t'<0.33 & mtr_all_b_`u'_`t'>-0.33, ysca(r(-0.33 0.33)) yline(0) ylabel(-0.3 (0.1) 0.3) title("") xtitle("hruby zisk (CZK/rok)") ytitle("zmena EMTR") note("") lineopts(lwidth(medthick) lcolor(orange))  msize(small) nodraw name(MTR_all_b_cz, replace) 
* Histograms of tax rates 
* (Histogram of income already exists)
hist mtr_all_w_`u'_`t' [fw=rpkoef] if ginc_w>inclb & ginc_w<2000000 & mtr_all_w_`u'_`t'<0.33 & mtr_all_w_`u'_`t'>-0.33, ysca(r(-0.33 0.33)) yline(0) ylabel(-0.3 (0.1) 0.3) frac horizontal ysca(alt) ytitle("zmena EMTR") xtitle("podil poplatniku") fxsize(33) name(hist_MTR_all_w_cz, replace) nodraw
hist mtr_all_b_`u'_`t' [fw=rpkoef] if ginc_b>inclb & ginc_b<2000000 & mtr_all_b_`u'_`t'<0.33 & mtr_all_b_`u'_`t'>-0.33, ysca(r(-0.33 0.33)) yline(0) ylabel(-0.3 (0.1) 0.3) frac horizontal ysca(alt) ytitle("zmena EMTR") xtitle("podil poplatniku") fxsize(33) name(hist_MTR_all_b_cz, replace) nodraw
* Combine work and business
graph combine MTR_all_w_cz MTR_all_b_cz, ycommon title("Zmena efektivnich danovych sazeb") nodraw saving(MTR_all_w_b_cz, replace)
* Combine EMTR and histogram
graph combine MTR_all_w_cz hist_MTR_all_w_cz, ycommon title("Zmena efektivnich danovych sazeb: prijmy ze zamestnani") imargin() nodraw saving(MTR_all_w_densities_cz, replace)
graph combine MTR_all_b_cz hist_MTR_all_b_cz, ycommon title("Zmena efektivnich danovych sazeb: prijmy z podnikani") imargin() nodraw saving(MTR_all_b_densities_cz, replace)

*** Plot Lorenz curves
* Individual - all income - Czech version
sort glvar_ginc_i pvar_ginc_i
twoway line glvar_totaltax_i_`t' glvar_ginc_i pvar_ginc_i pvar_ginc_i if ginc_i>inclb, ylabel(0 (0.1) 1, grid) xlabel(0 (0.1) 1, grid) xtitle(" ") name(lorenz_i_`t'_cz, replace ) legend(off) title("pred reformou") nodraw
twoway line glvar_totaltax_i_`u' glvar_ginc_i pvar_ginc_i pvar_ginc_i if ginc_i>inclb, ylabel(0 (0.1) 1, grid) xlabel(0 (0.1) 1, grid) xtitle(" ") name(lorenz_i_`u'_cz, replace ) legend(off) title("po reforme") nodraw
graph combine lorenz_i_`t'_cz lorenz_i_`u'_cz, title("Lorenzovy krivky: celkove dane a prijmy") subtitle("jednotlivci, vsechny prijmy") l2title("kumulativni podil na prijmu ci danich") b2title("kumulativni podil v populaci dle prijmu") nodraw saving(lorenz_comp_i_cz, replace)
* Households - gross income and net taxes per unit - Czech version
sort glvar_hhginc_pu pvar_hhginc_pu
twoway line glvar_hhnettax_pu_`t' glvar_hhginc_pu pvar_hhginc_pu pvar_hhginc_pu if vztah==1 & hhnonpen==1, ylabel(0 (0.1) 1, grid) xlabel(0 (0.1) 1, grid) xtitle(" ") name(lorenz_hh_`t'_cz, replace ) legend(off) title("pred reformou") nodraw
twoway line glvar_hhnettax_pu_`u' glvar_hhginc_pu pvar_hhginc_pu pvar_hhginc_pu if vztah==1 & hhnonpen==1, ylabel(0 (0.1) 1, grid) xlabel(0 (0.1) 1, grid) xtitle(" ") name(lorenz_hh_`u'_cz, replace ) legend(off) title("po reforme") nodraw
graph combine lorenz_hh_`t'_cz lorenz_hh_`u'_cz, title("Lorenzovy krivky: ciste dane a prijmy") subtitle("domacnosti, na spotrebni jednotku") l2title("kumulativni podil na prijmu nebo cistych danich") b2title("kumulativni podil v populaci dle prijmu") nodraw saving(lorenz_comp_hh_cz, replace)

**** Household-level net taxes and ATRs
* HH level net tax per unit - change
lpoly hhnettax_perunit_`u'_`t' hhginc_perunit if vztah==1 & hhnonpen==1 & hhnettax_perunit_`u'_`t'>=-50000 & hhnettax_perunit_`u'_`t'<=30000, title("") xsca(alt) yline(0) ysc(r(-50000 30000)) ylabel(-50000 (20000) 30000) xtitle("hruba mzda domacnosti na jednotku, Kc za rok") ytitle("zmena v cistych danich na jednotku domacnosti") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(hhnettax, replace) 
hist hhnettax_perunit_`u'_`t' [fw=rpkoef] if vztah==1 & hhnonpen==1 & hhnettax_perunit_`u'_`t'>=-50000 & hhnettax_perunit_`u'_`t'<=30000, frac horizontal xsca(alt) ysca(alt) yline(0) ysc(r(-50000 30000)) ylabel(-50000 (20000) 30000) ytitle("zmena v cistych danich na jednotku domacnosti") xtitle("podil domacnosti") fxsize(33) name(hist_hhnettax, replace) nodraw
graph combine hhnettax hist_hhnettax, title("Zmena v cistych danich na jednotku domacnosti") imargin() nodraw saving(hhnettax_densities_cz, replace)
* HH level net tax (total) - change
lpoly hhnettax_i_`u'_`t' hhginc_i if vztah==1 & hhnonpen==1 & hhnettax_i_`u'_`t'>=-90000 & hhnettax_i_`u'_`t'<=50000, title("") xsca(alt) yline(0) ysc(r(-90000 50000)) ylabel(-90000 (20000) 50000) xtitle("hruby prijem domacnosti, Kc za rok") ytitle("zmena v celkovych cistych danich domacnosti") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(hhnettax2, replace) 
hist hhnettax_i_`u'_`t' [fw=rpkoef] if vztah==1 & hhnonpen==1 & hhnettax_i_`u'_`t'>=-90000 & hhnettax_i_`u'_`t'<=50000, frac horizontal xsca(alt) ysca(alt) yline(0) ysc(r(-90000 50000)) ylabel(-90000 (20000) 50000) ytitle("zmena v celkovych cistych danich domacnosti") xtitle("podil domacnosti") fxsize(33) name(hist_hhnettax2, replace) nodraw
graph combine hhnettax2 hist_hhnettax2, title("Celkova zmena v cistych danich domacnosti") imargin() nodraw saving(hhnettax2_densities, replace)
* HH level ATR, net tax - change
lpoly phhATR_all_`u'_`t' hhginc_perunit if vztah==1 & hhnonpen==1 & hhginc_perunit<1200000 & phhATR_all_`u'_`t'<=0.75 & phhATR_all_`u'_`t'>=-0.25, title("") xsca(alt) yline(0) ysc(r(-0.25 0.75)) ylabel(-0.25 (0.25) 0.75) xtitle("hruba mzda domacnosti na jednotku, Kc za rok") ytitle("zmena v ATR (ciste dane) na urovni domacnosti") note("") lineopts(lwidth(medthick) lcolor(orange)) msize(small) nodraw name(hhATR_all, replace) 
hist phhATR_all_`u'_`t' [fw=rpkoef] if vztah==1 & hhnonpen==1 & hhginc_perunit<1200000 & phhATR_all_`u'_`t'<=0.75 & phhATR_all_`u'_`t'>=-0.25, frac horizontal xsca(alt) ysca(alt) yline(0) ysc(r(-0.25 0.75)) ylabel(-0.25 (0.25) 0.75) ytitle("zmena v ATR (ciste dane) na urovni domacnosti") xtitle("podil domacnosti") fxsize(33) name(hist_hhATR_all, replace) nodraw
graph combine hhATR_all hist_hhATR_all, title("Zmena v ATR pro ciste dane, domacnosti") imargin() nodraw saving(hhATR_all_densities_cz, replace)

cd ../..

end
